[![Build Status](https://travis-ci.org/aiidateam/aiida-metapkg.svg?branch=master)](https://travis-ci.org/aiidateam/aiida-metapkg)

# <img src="logos/AiiDA_transparent_logo.png" alt="AiiDA" width=200/>

**Automated Interactive Infrastructure and Database for Computational
Science**

AiiDA (www.aiida.net) is a workflow manager for computational science with a strong focus on provenance, performance and extensibility.

## Metapackage

The `aiida` package is an alias for the `aiida-core` package, which contains the actual implementation.

Please see the  [`aiida-core`](https://github.com/aiidateam/aiida-core) repository for any further information on AiiDA.

## Acknowledgements

This work is supported by the [MARVEL National Centre for Competency in
Research](<http://nccr-marvel.ch>) funded by the [Swiss National
Science Foundation](<http://www.snf.ch/en>), as well as by the [MaX
European Centre of Excellence](<http://www.max-centre.eu/>) funded by
the Horizon 2020 EINFRA-5 program, Grant No. 676598.

<img src="logos/MARVEL.png" alt="MARVEL" height="50"/><img src="logos/MaX.png" alt="MaX" height="50"/>
